@@ -26,13 +26,13 @@ class Worker:
         create_producer=False,
         on_run=None,
         sasl_opts={},
+        consumer_opts={},
     ):
         loop = asyncio.get_event_loop()
         self._kafka_broker_addr = kafka_broker_addr
         self._kafka_group_id = kafka_group_id
         self._consumer_topic = consumer_topic
         self._producer_topic = producer_topic
-        self._on_run = on_run
         if not producer_topic:
             self._producer_topic = consumer_topic
         self._consumer = None
@@ -51,13 +51,20 @@ class Worker:
 
         if create_consumer:
             self._consumer = Worker.make_consumer(
-                loop, kafka_broker_addr, kafka_group_id, sasl_opts
+                loop, kafka_broker_addr, kafka_group_id, sasl_opts, consumer_opts
             )
         if create_producer:
             self._producer = Worker.make_producer(loop, kafka_broker_addr, sasl_opts)
 
+        # legacy code, to be removed in future releases
+        if on_run:
+            logger.warning(
+                f"DEPRECIATED: on_run should not be passed as param. Subclass the Worker"
+            )
+        self._on_run = on_run
+
     @classmethod
-    def make_consumer(cls, loop, broker_addr, group_id, sasl_opts={}):
+    def make_consumer(cls, loop, broker_addr, group_id, sasl_opts={}, consumer_opts={}):
         """
         Creates and connects Kafka  consumer to the broker
         :param loop:
@@ -65,9 +72,13 @@ class Worker:
         :return:
         """
         logger.debug("Creating instance of kafka consumer")
+
         if not sasl_opts:
             consumer = AIOKafkaConsumer(
-                loop=loop, bootstrap_servers=broker_addr, group_id=group_id,
+                loop=loop,
+                bootstrap_servers=broker_addr,
+                group_id=group_id,
+                **consumer_opts,
             )
         else:
             consumer = AIOKafkaConsumer(
@@ -79,6 +90,7 @@ class Worker:
                 sasl_plain_password=sasl_opts["password"],
                 security_protocol="SASL_SSL",
                 ssl_context=ssl.SSLContext(ssl.PROTOCOL_TLSv1_2),
+                **consumer_opts,
             )
 
         logger.info("Connected consumer to kafka on {}".format(broker_addr))
